@@ -1,5 +1,5 @@
 from omnipy import runtime
-from omnipy_examples.main import isajson
+from omnipy_examples.main import chatgpt, isajson
 from prefect import flow as prefect_flow
 
 
@@ -7,3 +7,9 @@ from prefect import flow as prefect_flow
 def isajson_prefect():
     runtime.config.engine = 'prefect'
     isajson()
+
+
+@prefect_flow
+def chatgpt_prefect():
+    runtime.config.engine = 'prefect'
+    chatgpt()
